Py4JJavaServer (py4j-java 0.10.0 API)
Date: 2016-04-18

py4j

## Interface Py4JJavaServer

- All Known Implementing Classes:
    GatewayServer, JavaServer

      public interface Py4JJavaServer

  Interface that describes the operations a server must support to receive requests from the Python side.

- - ### Method Summary

    All Methods Instance Methods Abstract Methods
    Modifier and Type | Method and Description
    --- | ---
    `void` | `addListener(GatewayServerListener listener)`
    `Gateway` | `getGateway()`
    `java.util.List<GatewayServerListener>` | `getListeners()`
    `void` | `shutdown()` Stops accepting connections, closes all current connections, and calls `Gateway.shutdown()`

- - ### Method Detail

    - #### getListeners

          java.util.List<GatewayServerListener> getListeners()

      Returns:
        An unmodifiable list of listeners

    - #### getGateway

          Gateway getGateway()

    - #### shutdown

          void shutdown()

      Stops accepting connections, closes all current connections, and calls `Gateway.shutdown()`

    - #### addListener

          void addListener(GatewayServerListener listener)